"""Backward-compatibility shim for salmalm.core.slash_commands_ext.

The actual implementation moved to salmalm.features.slash_commands_ext (v0.30.11).
"""
from salmalm.features.slash_commands_ext import *  # noqa: F401, F403
